@@ -29,13 +29,13 @@ def get_coastline(ds, lon_name, lat_name):
     lat_max = ds[lat_name].values.max()
     lat_min = ds[lat_name].values.min()
 
-    if  ((lon_max - lon_min) * (lat_max - lat_min))/(360**2) < 0.0016:
-        return '10m'
+    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360 ** 2) < 0.0016:
+        return "10m"
 
-    if  ((lon_max - lon_min) * (lat_max - lat_min))/(360**2) < 0.25:
-        return '50m'
+    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360 ** 2) < 0.25:
+        return "50m"
 
-    return '110m'
+    return "110m"
 
 
 def change_coords(dx):
@@ -109,7 +109,7 @@ def in_notebook():
     return "ipykernel" in sys.modules
 
 
-def ncplot(x, vars=None):
+def view(x, vars=None):
     """
     Plot the contents of a NetCDF file
     Parameters
@@ -121,8 +121,10 @@ def ncplot(x, vars=None):
 
     """
 
-    log = False
-    panel = False
+    coastline = True
+    if type(x) is xr.core.dataarray.DataArray:
+        x = x.to_dataset()
+
     if type(x) is xr.core.dataset.Dataset:
         xr_file = True
     else:
@@ -139,18 +141,55 @@ def ncplot(x, vars=None):
 
     quadmesh = False
 
-    if is_curvilinear(ds):
-        ds = change_coords(ds)
-        quadmesh = True
-
     df_dims = get_dims(ds)
     # figure out number of points
     lon_name = df_dims.longitude[0]
     lat_name = df_dims.latitude[0]
 
+    if quadmesh is False and lat_name is not None:
+        lats = ds[lat_name].values
+
+        max_step = np.max([np.abs(x) for x in (lats[0:-2] - lats[1:-1])])
+        min_step = np.min([np.abs(x) for x in (lats[0:-2] - lats[1:-1])])
+        if min_step == 0:
+            quadmesh = True
+        else:
+            if max_step / min_step > 1.001:
+                quadmesh = True
+
+    switch_coords = False
+
     if quadmesh:
-        lon_name = check_lon(lon_name, ds)
-        lat_name = check_lat(lat_name, ds)
+        switch_coords = True
+        if len(np.shape(ds[lon_name].values)) == 1:
+            switch_coords = False
+
+        if switch_coords:
+            if lon_name != check_lon(lon_name, ds):
+                lon_name = check_lon(lon_name, ds)
+                switch_coords = False
+                coastline = False
+            if lat_name != check_lat(lat_name, ds):
+                lat_name = check_lat(lat_name, ds)
+
+    if "long_name" in ds[lon_name]:
+        if "rotate" in ds[lon_name].long_name:
+            coastline = False
+
+        if "pole" in ds[lon_name].long_name:
+            coastline = False
+
+    if switch_coords:
+        orig_coords = list(ds.coords)
+        ds = change_coords(ds)
+        new_coords = list(ds.coords)
+        quadmesh = True
+        df_dims = get_dims(ds)
+        # figure out number of points
+        lon_name = df_dims.longitude[0]
+        lat_name = df_dims.latitude[0]
+        if orig_coords != new_coords:
+            coastline = False
 
     n_points = 1
     if lon_name is not None:
@@ -223,7 +262,6 @@ def ncplot(x, vars=None):
         if len(vars) == 1:
             vars = vars[0]
 
-
     if type(vars) is list:
         for vv in vars:
             if vv not in list(ds.variables):
@@ -252,7 +290,6 @@ def ncplot(x, vars=None):
 
     # line plot
 
-
     if len([x for x in coord_df.length if x > 1]) == 1:
 
         df = ds.to_dataframe().reset_index()
@@ -268,41 +305,21 @@ def ncplot(x, vars=None):
 
         df = df.loc[:, selection].melt(x_var).drop_duplicates().set_index(x_var)
 
-        if panel:
-            intplot = df.hvplot(
-                by="variable",
-                logy=log,
-                subplots=True,
-                shared_axes=False,
-                responsive=(in_notebook() is False),
-            )
-            if in_notebook():
-                return intplot
+        intplot = df.hvplot(
+            groupby="variable",
+            dynamic=True,
+            responsive=(in_notebook() is False),
+        )
+        if in_notebook():
+            return intplot
 
-            t = Thread(target=ctrc)
-            t.start()
+        t = Thread(target=ctrc)
+        t.start()
 
-            bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
-                threaded=False
-            )
-            return None
-        else:
-            intplot = df.hvplot(
-                groupby="variable",
-                logy=log,
-                dynamic=True,
-                responsive=(in_notebook() is False),
-            )
-            if in_notebook():
-                return intplot
-
-            t = Thread(target=ctrc)
-            t.start()
-
-            bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
-                threaded=False
-            )
-            return None
+        bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
+            threaded=False
+        )
+        return None
 
     # heat map where 2 coords have more than 1 value, not a spatial map
     if len([x for x in coord_df.length if x > 1]) == 2:
@@ -328,14 +345,9 @@ def ncplot(x, vars=None):
         if case1 <= 1:
 
             if type(vars) is list:
-                intplot = df.drop_duplicates().hvplot.heatmap(
-                    x=x_var,
-                    y=y_var,
-                    C="value",
-                    groupby="variable",
-                    colorbar=True,
-                    cmap="viridis",
-                )
+
+                intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis")
+
             else:
 
                 self_max = ds.rename({vars: "x"}).x.max()
@@ -343,29 +355,17 @@ def ncplot(x, vars=None):
                 v_max = float(max(self_max.values, -self_min.values))
 
                 if self_max > 0 and self_min < 0:
+                    intplot = ds.hvplot.image(
+                        x_var,
+                        y_var,
+                        vars,
+                        cmap="RdBu_r",
+                        rasterize=True,
+                        responsive=(in_notebook() is False),
+                    ).redim.range(**{vars: (-v_max, v_max)})
 
-                    intplot = (
-                        df.drop_duplicates()
-                        .hvplot.heatmap(
-                            x=x_var,
-                            y=y_var,
-                            C="value",
-                            groupby="variable",
-                            colorbar=True,
-                            cmap="RdBu_r",
-                            responsive=(in_notebook() is False),
-                        )
-                        .opts(clim=(-v_max, v_max))
-                    )
                 else:
-                    intplot = df.drop_duplicates().hvplot.heatmap(
-                        x=x_var,
-                        y=y_var,
-                        C="value",
-                        groupby="variable",
-                        colorbar=True,
-                        cmap="viridis",
-                    )
+                    intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis")
 
             if in_notebook():
                 return intplot
@@ -486,93 +486,71 @@ def ncplot(x, vars=None):
 
         df = df.drop(columns=to_go).drop_duplicates()
 
-        if panel:
-            intplot = (
-                df.set_index(time_name)
-                .loc[:, vars]
-                .reset_index()
-                .melt(time_name)
-                .set_index(time_name)
-                .hvplot(
-                    by="variable",
-                    logy=log,
-                    subplots=True,
-                    shared_axes=False,
-                    responsive=(in_notebook() is False),
-                )
+        intplot = (
+            df.reset_index()
+            .set_index(time_name)
+            .loc[:, vars]
+            .reset_index()
+            .melt(time_name)
+            .set_index(time_name)
+            .hvplot(
+                groupby="variable",
+                dynamic=True,
+                responsive=(in_notebook() is False),
             )
-            if in_notebook():
-                return intplot
+        )
+        if in_notebook():
+            return intplot
 
-            t = Thread(target=ctrc)
-            t.start()
+        t = Thread(target=ctrc)
+        t.start()
 
-            bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
-                threaded=False
-            )
-            return None
-
-        else:
-            intplot = (
-                df.reset_index()
-                .set_index(time_name)
-                .loc[:, vars]
-                .reset_index()
-                .melt(time_name)
-                .set_index(time_name)
-                .hvplot(
-                    groupby="variable",
-                    logy=log,
-                    dynamic=True,
-                    responsive=(in_notebook() is False),
-                )
-            )
-            if in_notebook():
-                return intplot
-
-            t = Thread(target=ctrc)
-            t.start()
-
-            bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
-                threaded=False
-            )
-            return None
+        bokeh_server = pn.panel(intplot, sizing_mode="stretch_both").show(
+            threaded=False
+        )
+        return None
 
     if (n_points > 1) and (n_levels >= 1) and (type(vars) is list):
 
-        if is_curvilinear(ds):
+        if quadmesh:
 
-            coastline = get_coastline(ds, lon_name, lat_name)
+            if coastline:
+                coastline = get_coastline(ds, lon_name, lat_name)
+                projection = ccrs.PlateCarree()
+            else:
+                projection = None
 
+            print(lon_name)
+            print(lat_name)
+            print(vars)
             intplot = ds.hvplot.quadmesh(
                 lon_name,
                 lat_name,
                 vars,
                 dynamic=True,
                 cmap="viridis",
-                logz=log,
-                coastline = coastline,projection=ccrs.PlateCarree(),
-                rasterize = True,
+                coastline=coastline,
+                projection=projection,
+                rasterize=True,
                 responsive=in_notebook() is False,
             )
-            # intplot = pn.Column(pn.WidgetBox(w1), intplot)
         else:
 
-            # w1 = pn.widgets.Select(name='Coastline', options=[True, False])
-
-            coastline = get_coastline(ds, lon_name, lat_name)
+            if coastline:
+                coastline = get_coastline(ds, lon_name, lat_name)
+                projection = ccrs.PlateCarree()
+            else:
+                projection = None
             intplot = ds.hvplot.image(
                 lon_name,
                 lat_name,
                 vars,
                 dynamic=True,
                 cmap="viridis",
-                logz=log,
-                coastline = coastline,
-                projection=ccrs.PlateCarree(),
+                coastline=coastline,
+                projection=projection,
                 responsive=in_notebook() is False,
             )
-            # intplot = pn.Column(pn.WidgetBox(w1), intplot)
 
         if in_notebook():
             return intplot
@@ -595,35 +573,42 @@ def ncplot(x, vars=None):
         v_max = max(self_max.values, -self_min.values)
 
         if (self_max.values > 0) and (self_min.values < 0):
-            if is_curvilinear(ds):
-                # w1 = pn.widgets.Select(name='Coastline', options=[True, False])
-                coastline = get_coastline(ds, lon_name, lat_name)
+            if quadmesh:
+                if coastline:
+                    coastline = get_coastline(ds, lon_name, lat_name)
+                    projection = ccrs.PlateCarree()
+                else:
+                    projection = None
+
                 intplot = ds.hvplot.quadmesh(
                     lon_name,
                     lat_name,
                     vars,
                     dynamic=True,
-                    logz=log,
                     cmap="RdBu_r",
-                    rasterize = True,
+                    coastline=coastline,
+                    projection=projection,
+                    rasterize=True,
                     responsive=(in_notebook() is False),
                 ).redim.range(**{vars: (-v_max, v_max)})
                 # intplot = pn.Row(pn.WidgetBox(w1), intplot)
             else:
-                # w1 = pn.widgets.Select(name='Coastline', options=[True, False])
-                coastline = get_coastline(ds, lon_name, lat_name)
+                if coastline:
+                    coastline = get_coastline(ds, lon_name, lat_name)
+                    projection = ccrs.PlateCarree()
+                else:
+                    projection = None
+
                 intplot = ds.hvplot.image(
                     lon_name,
                     lat_name,
                     vars,
                     dynamic=True,
-                    logz=log,
-                    coastline = coastline,
-                    projection=ccrs.PlateCarree(),
+                    coastline=coastline,
+                    projection=projection,
                     cmap="RdBu_r",
                     responsive=(in_notebook() is False),
                 ).redim.range(**{vars: (-v_max, v_max)})
-                # intplot = pn.Row(pn.WidgetBox(w1), intplot)
 
             if in_notebook():
                 return intplot
@@ -636,28 +621,39 @@ def ncplot(x, vars=None):
             return None
 
         else:
-            if is_curvilinear(ds):
+            if quadmesh:
+                if coastline:
+                    coastline = get_coastline(ds, lon_name, lat_name)
+                    projection = ccrs.PlateCarree()
+                else:
+                    projection = None
                 intplot = ds.hvplot.quadmesh(
                     lon_name,
                     lat_name,
                     vars,
                     dynamic=True,
-                    logz=log,
                     cmap="viridis",
-                    rasterize = True,
+                    coastline=coastline,
+                    projection=projection,
+                    rasterize=True,
                     responsive=(in_notebook() is False),
                 ).redim.range(**{vars: (self_min.values, v_max)})
             else:
 
-                coastline = get_coastline(ds, lon_name, lat_name)
+                if coastline:
+                    coastline = get_coastline(ds, lon_name, lat_name)
+                    projection = ccrs.PlateCarree()
+                else:
+                    projection = None
+
                 intplot = ds.hvplot.image(
                     lon_name,
                     lat_name,
                     vars,
                     dynamic=True,
-                    logz=log,
                     cmap="viridis",
-                    coastline = coastline,
+                    coastline=coastline,
+                    projection=projection,
                     responsive=(in_notebook() is False),
                 ).redim.range(**{vars: (self_min.values, v_max)})
 
