@@ -14,7 +14,12 @@ def check_lon(x, ds):
     news = ds.coords[x]
     possibles = [i for i in list(news.coords) if i in dims]
 
+    for pp in possibles:
+        if "lon" in pp:
+            return pp
+
     if len(possibles) == 2:
+        # longitude should come after latitude alaphabetically
         if possibles[0] < possibles[1]:
             return possibles[0]
         else:
@@ -28,7 +33,13 @@ def check_lat(x, ds):
     news = ds.coords[x]
     possibles = [i for i in list(news.coords) if i in dims]
 
+    for pp in possibles:
+        if "lat" in pp:
+            return pp
+
     if len(possibles) == 2:
+        # longitude should come before latitude alaphabetically
+
         if possibles[0] > possibles[1]:
             return possibles[0]
         else:
@@ -46,26 +57,32 @@ def get_dims(ff):
             ds = xr.open_dataset(ff)
 
         ff_dims = list(ds.coords)
-        var = [x for x in ds.variables.keys() if x not in ff_dims][0]
+
+        max_dim = 0
+
+        vars = [x for x in list(ds.variables.keys()) if x not in list(ds.coords)]
+
         ds = ds.metpy.parse_cf()
 
-        try:
-            for x in ds[var].metpy.coordinates("longitude"):
-                lon_name = x.name
-        except:
-            lon_name = None
+        for var in vars:
 
-        try:
-            for x in ds[var].metpy.coordinates("latitude"):
-                lat_name = x.name
-        except:
-            lat_name = None
+            try:
+                for x in ds[var].metpy.coordinates("longitude"):
+                    lon_name = x.name
+            except:
+                lon_name = lon_name
 
-        try:
-            for x in ds[var].metpy.coordinates("time"):
-                time_name = x.name
-        except:
-            time_name = None
+            try:
+                for x in ds[var].metpy.coordinates("latitude"):
+                    lat_name = x.name
+            except:
+                lat_name = lat_name
+
+            try:
+                for x in ds[var].metpy.coordinates("time"):
+                    time_name = x.name
+            except:
+                time_name = lat_name
 
         # it's possible metpy will not parse lat/lon properly. In this case check if "lon"/"lat" appear in dims once
         if lon_name is None or lat_name is None:
